Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
server.py | setup_logging | 16 | 0 | 0 | 100%
server.py | SimpleCache.__init__ | 6 | 0 | 0 | 100%
server.py | SimpleCache.get | 10 | 0 | 0 | 100%
server.py | SimpleCache.set | 4 | 0 | 0 | 100%
server.py | SimpleCache.clear | 1 | 0 | 0 | 100%
server.py | SimpleCache.get_stats | 1 | 0 | 0 | 100%
server.py | ElasticsearchClient.__init__ | 12 | 0 | 0 | 100%
server.py | ElasticsearchClient.safe_elasticsearch_query | 39 | 18 | 0 | 54%
server.py | ElasticsearchClient.search_packages | 18 | 4 | 0 | 78%
server.py | ElasticsearchClient.search_options | 18 | 13 | 0 | 28%
server.py | ElasticsearchClient.search_programs | 21 | 4 | 0 | 81%
server.py | ElasticsearchClient.search_packages_with_version | 12 | 12 | 0 | 0%
server.py | ElasticsearchClient.advanced_query | 6 | 0 | 0 | 100%
server.py | ElasticsearchClient.get_package_stats | 3 | 3 | 0 | 0%
server.py | ElasticsearchClient.get_package | 11 | 3 | 0 | 73%
server.py | ElasticsearchClient.get_option | 11 | 6 | 0 | 45%
server.py | NixOSContext.__init__ | 2 | 0 | 0 | 100%
server.py | NixOSContext.get_status | 1 | 0 | 0 | 100%
server.py | NixOSContext.get_package | 1 | 0 | 0 | 100%
server.py | NixOSContext.search_packages | 1 | 0 | 0 | 100%
server.py | NixOSContext.search_options | 1 | 0 | 0 | 100%
server.py | NixOSContext.get_option | 1 | 0 | 0 | 100%
server.py | NixOSContext.search_programs | 1 | 1 | 0 | 0%
server.py | NixOSContext.search_packages_with_version | 1 | 1 | 0 | 0%
server.py | NixOSContext.advanced_query | 1 | 1 | 0 | 0%
server.py | NixOSContext.get_package_stats | 1 | 1 | 0 | 0%
server.py | app_lifespan | 12 | 12 | 0 | 0%
server.py | create_wildcard_query | 5 | 5 | 0 | 0%
server.py | status_resource | 2 | 0 | 0 | 100%
server.py | package_resource | 2 | 0 | 0 | 100%
server.py | search_packages_resource | 2 | 0 | 0 | 100%
server.py | search_options_resource | 2 | 0 | 0 | 100%
server.py | option_resource | 2 | 0 | 0 | 100%
server.py | search_programs_resource | 2 | 0 | 0 | 100%
server.py | package_stats_resource | 2 | 0 | 0 | 100%
server.py | search_nixos | 100 | 36 | 0 | 64%
server.py | get_nixos_package | 44 | 9 | 0 | 80%
server.py | get_nixos_option | 26 | 5 | 0 | 81%
server.py | advanced_search | 35 | 11 | 0 | 69%
server.py | package_statistics | 35 | 5 | 0 | 86%
server.py | version_search | 21 | 5 | 0 | 76%
server.py | (no function) | 81 | 7 | 0 | 91%
Total |  | 573 | 162 | 0 | 72%

No items found using the specified filter.